@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,7 +26,15 @@
 extern gboolean userbreak;
 
 
-GtkWidget *abort_dialog(const gchar *label);
+/******************************************************************************
+*                                                                             *
+* ja:中断ダイアログ関数群                                                     *
+*                                                                             *
+******************************************************************************/
+/*  ja:中断ダイアログ表示
+    label,説明文                                                            */
+GtkWidget *
+abort_dialog (const gchar *label);
 
 
 #endif
