@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -155,28 +155,37 @@ extern gsize charset_leng[];
 extern guchar charset_space[];
 
 
-/*  フォントの幅と高さを取得する
+/******************************************************************************
+*                                                                             *
+* ja:キャラクターセット関数群                                                 *
+*                                                                             *
+******************************************************************************/
+/*  ja:フォントの幅と高さを取得する
       layout,レイアウト
        width,幅
       height,高さ
     font_buf,バッファ                                                       */
 void
-charset_size (PangoLayout *layout, gint *width, gint *height,
-                                                            guint8 *font_buf);
+charset_size (PangoLayout *layout,
+              gint        *width,
+              gint        *height,
+              guint8      *font_buf);
 
 
-/*  表示上の半角単位の文字幅を求める
+/*  ja:表示上の半角単位の文字幅を求める
       layout,レイアウト
         text,文字
        width,幅
     font_buf,バッファ
          RET,半角単位                                                       */
 gint
-charset_width (PangoLayout *layout, const gchar *text,
-                                        const gint width, guint8 *font_buf);
+charset_width (PangoLayout *layout,
+               const gchar *text,
+               const gint   width,
+               guint8      *font_buf);
 
 
-/*  文字の種類を返す
+/*  ja:文字の種類を返す
     text,文字
      RET,文字の種類                                                         */
 gint
