@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,75 +23,90 @@
 #include "tmaid.h"
 
 
-/*  ラインバッファを求める
+/*  ja:ラインバッファを求める
     start,ラインバッファ
       off,現在のy座標
         y,y座標
       RET,ラインバッファ                                                    */
-LineBuffer *edit_get_line_buf(LineBuffer **start,gint *off,const gint y);
+LineBuffer *
+edit_get_line_buf (LineBuffer **start,
+                   gint        *off,
+                   const gint   y);
 
 
-/*  桁数を取得する
-    ptw,TXTウインドウ情報
-      y,行
-    RET,桁数                                                                */
-gint edit_get_width(TmaidWindow *tmaid,const gint y);
+/*  ja:桁数を取得する
+    tmaid,ウインドウ情報
+        y,行
+      RET,桁数                                                              */
+gint
+edit_get_width (TmaidWindow *tmaid,
+                const gint   y);
 
 
-/*  最大桁数を取得する
-    ptw,TXTウインドウ情報
-    RET,桁数                                                                */
-gint edit_get_width_max(TmaidWindow *tmaid);
+/*  ja:最大桁数を取得する
+    tmaid,ウインドウ情報
+      RET,桁数                                                              */
+gint
+edit_get_width_max (TmaidWindow *tmaid);
 
 
-/*  キャレットのアライメントされたx座標を求める
-      ptw,TXTウインドウ情報
+/*  ja:キャレットのアライメントされたx座標を求める
+    tmaid,ウインドウ情報
         x,x座標
         y,y座標
     align,TRUE:右に寄せる,FALSE:左に寄せる
       RET,座標                                                              */
-gint edit_get_align_pos(TmaidWindow *tmaid,const gint x,const gint y,
-                                                        const gboolean align);
+gint
+edit_get_align_pos (TmaidWindow    *tmaid,
+                    const gint      x,
+                    const gint      y,
+                    const gboolean  align);
 
 
-/*  画面上の座標からラインバッファ上のアドレスを求める
-      ptw,TXTウインドウ情報
+/*  ja:画面上の座標からラインバッファ上のアドレスを求める
+    tmaid,ウインドウ情報
         x,x座標
         y,y座標
     align,TRUE:右に寄せる,FALSE:左に寄せる
       RET,アドレス                                                          */
-gint edit_get_data_pos(TmaidWindow *tmaid,const gint x,const gint y,
-                                                        const gboolean align);
+gint
+edit_get_data_pos (TmaidWindow    *tmaid,
+                   const gint      x,
+                   const gint      y,
+                   const gboolean  align);
 
 
-/*  ラインバッファ上のアドレスから画面上の座標を求める
-    ptw,TXTウインドウ情報
-      x,x座標
-      y,y座標
-    RET,座標                                                                */
-gint edit_get_screen_pos(TmaidWindow *tmaid,const gint x,const gint y);
+/*  ja:ラインバッファ上のアドレスから画面上の座標を求める
+    tmaid,ウインドウ情報
+        x,x座標
+        y,y座標
+      RET,座標                                                              */
+gint
+edit_get_screen_pos (TmaidWindow *tmaid,
+                     const gint   x,
+                     const gint   y);
 
 
 /*  ja:区切りを求める
-     ptw,TXTウインドウ情報
-       x,x座標
-       y,y座標
-    move,TRUE:右に移動する,FALSE:左に移動する
-     RET,座標                                                               */
+    tmaid,ウインドウ情報
+        x,x座標
+        y,y座標
+     move,TRUE:右に移動する,FALSE:左に移動する
+      RET,座標                                                              */
 gint
 edit_get_move_pos (TmaidWindow *tmaid, const gint x, const gint y,
                                                         const gboolean move);
 
 
 /*  ja:単語を選択する
-    tmaid,TXTウインドウ情報
+    tmaid,ウインドウ情報
       RET,TRUE:単語あり,FALSE:単語なし                                      */
 gboolean
 edit_select_word (TmaidWindow *tmaid);
 
 
 /*  指定範囲のバイト数を求める
-         ptw,TXTウインドウ情報
+       tmaid,ウインドウ情報
      start_p,選択範囲
        end_p,選択範囲
          RET,バイト数                                                       */
@@ -99,7 +114,7 @@ gint edit_get_sel_bytes(TmaidWindow *tmaid,GdkPoint *start_p,GdkPoint *end_p);
 
 
 /*  指定範囲をメモリにコピーする
-        ptw,TXTウインドウ情報
+      tmaid,ウインドウ情報
     start_p,選択範囲
       end_p,選択範囲
        text,メモリ                                                          */
@@ -108,7 +123,7 @@ void edit_cpy_sel_mem(TmaidWindow *tmaid,GdkPoint *start_p,GdkPoint *end_p,
 
 
 /*  メモリの内容を貼り付ける
-       ptw,TXTウインドウ情報
+     tmaid,ウインドウ情報
        put,貼り付ける座標
        new,新しい座標
       text,メモリ
@@ -119,7 +134,7 @@ gint edit_put_mem(TmaidWindow *tmaid,GdkPoint *put,GdkPoint *new,
 
 
 /*  指定範囲を削除する
-        ptw,TXTウインドウ情報
+      tmaid,ウインドウ情報
     start_p,選択範囲
       end_p,選択範囲
         RET,削除された行数                                                  */
