@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,7 +23,14 @@
 #include "tmaid.h"
 
 
-void format_dialog(void);
+/******************************************************************************
+*                                                                             *
+* ja:ファイルタイプダイアログ関数群                                           *
+*                                                                             *
+******************************************************************************/
+/*  ja:ファイルタイプダイアログを表示する                                   */
+void
+format_dialog (void);
 
 
 #endif
