@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,6 +23,14 @@
 #include "tmaid.h"
 
 
+/******************************************************************************
+*                                                                             *
+* ja:ファイルタイプ選択ダイアログ関数群                                       *
+*                                                                             *
+******************************************************************************/
+/*  ja:ファイルタイプ選択ダイアログ表示
+    pos,選択されたファイルタイプ
+    RET,TRUE:OK,FALSE:Cancel                                                */
 gboolean ftype_dialog(gint *pos);
 
 
