@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,27 +25,33 @@
 
 /******************************************************************************
 *                                                                             *
-* ץѥƥؿ                                                            *
+* ja:プロパティ関数群                                                         *
 *                                                                             *
 ******************************************************************************/
-/*	ץѥƥ򥳥ԡ
-	ft_dst,ԡ
-	ft_src,ԡ															*/
+/*  ja:プロパティをコピーする
+    ft_dst,コピー先
+    ft_src,コピー元                                                         */
 void
-property_copy (FileType *ft_dst, FileType *ft_src);
+property_copy (FileType *ft_dst,
+               FileType *ft_src);
 
 
-/*	ץѥƥѹ
-	tmaid,TXTɥ
-	   ft,ե륿													*/
-void property_change(TmaidWindow *tmaid,FileType *ft);
+/*  ja:プロパティを変更する
+    tmaid,ウインドウ情報
+       ft,ファイルタイプ                                                    */
+void
+property_change (TmaidWindow *tmaid,
+                 FileType    *ft);
 
 
 /******************************************************************************
 *                                                                             *
-* ץѥƥؿ                                                  *
+* ja:プロパティダイアログ関数群                                               *
 *                                                                             *
 ******************************************************************************/
+/*  ja:プロパティダイアログ表示
+     ft,ファイルタイプ
+    RET,TRUE:OK,FALSE:Cancel                                                */
 gboolean property_dialog(FileType *ft);
 
 
