@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,13 +25,16 @@
 
 /******************************************************************************
 *                                                                             *
-* ɥؿ                                                    *
+* ja:リロードダイアログ関数群                                                 *
 *                                                                             *
 ******************************************************************************/
-
-
+/*  ja:リロードダイアログ表示
+      ft,ファイルタイプ
+    text,説明文
+     RET,TRUE:OK,FALSE:Cancel                                               */
 gboolean
-reload_dialog (FileType *ft, const gchar *text);
+reload_dialog (FileType    *ft,
+               const gchar *text);
 
 
 #endif
