@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,15 +23,25 @@
 #include "tmaid.h"
 
 
-typedef struct repinfo {
-	gboolean arrow;
-	gboolean ignorecase;
-	gchar *src,*dst;
-	GdkPoint start,end;
-} REPINFO;
+typedef struct ReplaceInfo_Tag
+{
+  gboolean arrow;
+  gboolean ignorecase;
+  gchar *src,*dst;
+  GdkPoint start,end;
+} ReplaceInfo;
 
 
-gint repinfo_dialog(REPINFO *rp);
+/******************************************************************************
+*                                                                             *
+* ja:置換情報ダイアログ関数群                                                 *
+*                                                                             *
+******************************************************************************/
+/*  ja:置換情報ダイアログ表示
+     ri,置換情報
+    RET,REPLACE_OK,REPLACE_NEXT,REPLACE_ALL,REPLACE_CANCEL                  */
+gint
+repinfo_dialog (ReplaceInfo *ri);
 
 
 #endif
