@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,13 +25,19 @@
 
 /******************************************************************************
 *                                                                             *
-* VOi/Cxg֐Q(eLXg)                                           *
+* ja:シグナル/イベント関数群(テキスト)                                        *
 *                                                                             *
 ******************************************************************************/
-gboolean signal_key_press(GtkWidget *widget,
-										GdkEventKey *event,TmaidWindow *tmaid);
 gboolean
-signal_key_release (GtkWidget *widget, GdkEventKey *event, TmaidWindow *tmaid);
+signal_key_press (GtkWidget   *widget,
+                  GdkEventKey *event,
+                  TmaidWindow *tmaid);
+
+
+gboolean
+signal_key_release (GtkWidget   *widget,
+                    GdkEventKey *event,
+                    TmaidWindow *tmaid);
 
 
 #endif
