@@ -25,42 +25,75 @@
 
 /******************************************************************************
 *                                                                             *
-* シグナル/イベント関数群(テキスト)                                           *
+* ja:シグナル/イベント関数群(テキスト)                                        *
 *                                                                             *
 ******************************************************************************/
-void signal_style_set(GtkWidget *widget,GtkStyle *style,gpointer user_data);
+void signal_style_set (GtkWidget *widget,
+                       GtkStyle  *style,
+                       gpointer   user_data);
 
 
 /******************************************************************************
 *                                                                             *
-* シグナル/イベント関数群(メニュー)                                           *
+* ja:シグナル/イベント関数群(メニュー)                                        *
 *                                                                             *
 ******************************************************************************/
-void signal_activate_menu_window(GtkWidget *widget,GtkWidget *child);
-void signal_activate_menu_history(GtkWidget *widget,gchar *file);
-void signal_destroy_menu_history(GtkWidget *widget,gchar *file);
+void
+signal_activate_menu_window (GtkWidget *widget,
+                             GtkWidget *child);
+
+
+void
+signal_activate_menu_history (GtkWidget *widget,
+                              gchar     *file);
+
+
+void
+signal_destroy_menu_history (GtkWidget *widget,
+                             gchar     *file);
 
 
 /******************************************************************************
 *                                                                             *
-* シグナル/イベント関数群(ノート)                                             *
+* ja:シグナル/イベント関数群(ノート)                                          *
 *                                                                             *
 ******************************************************************************/
-void signal_clicked(GtkWidget *widget,GtkWidget *child);
-void signal_switch_page(GtkNotebook *notebook,GtkNotebookPage *page,
-											gint page_num,gpointer user_data);
-void signal_destroy_notebook(GtkWidget *widget,gpointer user_data);
+void
+signal_clicked (GtkWidget *widget,
+                GtkWidget *child);
+
+
+void
+signal_switch_page (GtkNotebook     *notebook,
+                    GtkNotebookPage *page,
+                    gint             page_num,
+                    gpointer         user_data);
+
+
+void
+signal_destroy_notebook (GtkWidget *widget,
+                         gpointer   user_data);
 
 
 /******************************************************************************
 *                                                                             *
-* シグナル/イベント関数群(セレクション)                                       *
+* ja:シグナル/イベント関数群(セレクション)                                    *
 *                                                                             *
 ******************************************************************************/
-void signal_drag_data_received(GtkWidget *widget,GdkDragContext *context,
-		gint x,gint y,GtkSelectionData *selection_data,guint info,guint time);
-gboolean signal_selection_clear(GtkWidget *widget,GdkEventSelection *event,
-														gpointer user_data);
+void
+signal_drag_data_received (GtkWidget        *widget,
+                           GdkDragContext   *context,
+                           gint              x,
+                           gint              y,
+                           GtkSelectionData *selection_data,
+                           guint             info,
+                           guint             time);
+
+
+gboolean
+signal_selection_clear (GtkWidget         *widget,
+                        GdkEventSelection *event,
+                        gpointer           user_data);
 
 
 void
@@ -74,8 +107,8 @@ signal_selection_get (GtkWidget        *widget,
 void
 signal_selection_received (GtkWidget        *widget,
                            GtkSelectionData *data,
-                           guint time,
-                           gpointer user_data);
+                           guint             time,
+                           gpointer          user_data);
 
 
 void
@@ -86,11 +119,18 @@ signal_selection_recv (GObject   *object,
 
 /******************************************************************************
 *                                                                             *
-* シグナル/イベント関数群(メイン)                                             *
+* ja:シグナル/イベント関数群(メイン)                                          *
 *                                                                             *
 ******************************************************************************/
-gboolean signal_delete(GtkWidget *widget,GdkEvent *event,gpointer user_data);
-void signal_destroy_window(GtkWidget *widget,gpointer user_data);
+gboolean
+signal_delete (GtkWidget *widget,
+               GdkEvent  *event,
+               gpointer   user_data);
+
+
+void
+signal_destroy_window (GtkWidget *widget,
+                       gpointer   user_data);
 
 
 #endif
