@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,7 +23,16 @@
 #include "tmaid.h"
 
 
-gboolean valchr_dialog(gchar *valchr);
+/******************************************************************************
+*                                                                             *
+* ja:コード文字入力ダイアログ関数群                                           *
+*                                                                             *
+******************************************************************************/
+/*  ja:コード文字入力ダイアログ表示
+    valchr,入力文字
+       RET,TRUE:OK,FALSE:Cancel                                             */
+gboolean
+valchr_dialog (gchar *valchr);
 
 
 #endif
